@@ -2,6 +2,7 @@
 
 use anyhow::Result;
 use delay_timer::prelude::*;
+use delay_timer::utils::convenience::functions::unblock_process_task_fn;
 use smol::Timer;
 use std::time::Duration;
 
@@ -9,7 +10,9 @@ use std::time::Duration;
 #[async_std::main]
 async fn main() -> Result<()> {
     // Build an DelayTimer that uses the default configuration of the Smol runtime internally.
-    let delay_timer = DelayTimerBuilder::default().build();
+    let delay_timer = DelayTimerBuilder::default()
+        .smol_runtime_by_default()
+        .build();
 
     // Develop a print job that runs in an asynchronous cycle.
     let task_instance_chain = delay_timer.insert_task(build_task_async_print()?)?;
@@ -40,29 +43,32 @@ async fn main() -> Result<()> {
 fn build_task_async_print() -> Result<Task, TaskError> {
     let mut task_builder = TaskBuilder::default();
 
-    let body = create_async_fn_body!({
+    let body = || async {
         println!("create_async_fn_body!");
 
         Timer::after(Duration::from_secs(3)).await;
 
         println!("create_async_fn_body:i'success");
-    });
+    };
 
     task_builder
         .set_task_id(1)
         .set_frequency_repeated_by_cron_str("*/6 * * * * * *")
         .set_maximum_parallel_runnable_num(2)
-        .spawn(body)
+        .spawn_async_routine(body)
 }
 
 fn build_task_async_execute_process() -> Result<Task, TaskError> {
+    let task_id = 3;
     let mut task_builder = TaskBuilder::default();
 
-    let body = unblock_process_task_fn("php /home/open/project/rust/repo/myself/delay_timer/examples/try_spawn.php >> ./try_spawn.txt".into());
+    let body = move || {
+        unblock_process_task_fn("php /home/open/project/rust/repo/myself/delay_timer/examples/try_spawn.php >> ./try_spawn.txt".into(), task_id)
+    };
     task_builder
         .set_frequency_by_candy(CandyFrequency::Repeated(CandyCron::Secondly))
-        .set_task_id(3)
+        .set_task_id(task_id)
         .set_maximum_running_time(10)
         .set_maximum_parallel_runnable_num(1)
-        .spawn(body)
+        .spawn_async_routine(body)
 }
