@@ -3,8 +3,14 @@
 use crate::prelude::*;
 use std::convert::TryFrom;
 use future_lite::block_on;
+use once_cell::sync::Lazy;
 
 
+/// Global internal status-reporter.
+pub(crate) static GLOBAL_STATUS_REPORTER: Lazy<(AsyncSender<PublicEvent>, AsyncReceiver<PublicEvent>)> = Lazy::new(|| {
+    smol::channel::unbounded()
+});
+
 /// # Required features
 ///
 /// This function requires the `status-report` feature of the `delay_timer`
@@ -142,6 +148,29 @@ impl TryFrom<&TimerEvent> for PublicEvent {
     }
 }
 
+impl TryFrom<TimerEvent> for PublicEvent {
+    type Error = anyhow::Error;
+
+    fn try_from(timer_event: TimerEvent) -> Result<Self, Self::Error> {
+        match timer_event {
+            TimerEvent::RemoveTask(task_id) => Ok(PublicEvent::RemoveTask(task_id)),
+            TimerEvent::AppendTaskHandle(_, delay_task_handler_box) => {
+                Ok(PublicEvent::RunningTask(delay_task_handler_box.get_task_id(), delay_task_handler_box.get_record_id()))
+            }
+            TimerEvent::FinishTask(finish_task_body) => {
+                // TODO: Be wary, clone can involve a lot of memory and consume performance.
+                Ok(PublicEvent::FinishTask(finish_task_body.into()))
+            }
+
+            TimerEvent::TimeoutTask(task_id, record_id) => {
+                Ok(PublicEvent::TimeoutTask(task_id, record_id))
+            }
+
+            _ => Err(anyhow!("PublicEvent only accepts timer_event some variant( RemoveTask, CancelTask ,FinishTask )!")),
+        }
+    }
+}
+
 impl PublicEvent {
     /// Get the task_id corresponding to the event.
    pub fn get_task_id(&self) -> u64 {
